==> gkn_bolts_survey-0.0.12.tar.gz: gkn_bolts_survey-0.0.12/gkn_bolts_survey/tests/test.py <==
import os
import sys
import time
# import traceback
import gkn_bolts_survey as bs


def log(*m):
    print(" ".join(map(str, m)))


def check_numpy():
    try:
        import numpy
        log("PASS", "NumPy installed")
    except ModuleNotFoundError:
        log("FAIL", "NumPy not installed")


def check_matplotlib():
    try:
        import matplotlib
        log("PASS", "matplotlib installed")
    except ModuleNotFoundError:
        log("FAIL", "matplotlib not installed")


def check_pandas():
    try:
        import pandas
        log("PASS", "pandas installed")
    except ModuleNotFoundError:
        log("FAIL", "pandas not installed")


def check_read_AtlasCopco_files():
    try:
        file_name = './test_AtlasCopco.xls'
        Signals = bs.read_signals(file_name)
        flag_pass = True
        if len(Signals) != 5:   flag_pass = False
        if abs(Signals[0].torque.sum() - 7827.592) > 0.1:   flag_pass = False
        if flag_pass:
            log("PASS", "read AtlasCopco files")
        else:
            log("FAIL", "read AtlasCopco files")
    except:
        log("FAIL", "read AtlasCopco files")


def check_read_Excel_files():
    try:
        file_name = './test_Excel.xlsx'
        Signals = bs.read_signals(file_name)
        flag_pass = True
        if len(Signals) != 4:   flag_pass = False
        if abs(Signals[0].torque.sum() - 2172.49) > 0.1:   flag_pass = False
        if flag_pass:
            log("PASS", "read Excel files")
        else:
            log("FAIL", "read Excel files")
    except:
        log("FAIL", "read Excel files")


def check_sigmoid_approximation():
    try:
        import numpy as np
        a_target = 40.0
        b_target = 0.05
        c_target = -2.0
        angle = np.linspace(0.0, 160.0, 100)
        torque =-(b_target*angle + c_target)
        torque = np.exp(torque) + 1
        torque = a_target / torque
        torque+= 1.3 * np.cos(angle*37.5) * np.sin(angle*15.3)
        signal = bs.SignalType(angle_filter=angle, torque_filter=torque)
        bs.sigmoid_approximation(signal)
        a_apx, b_apx, c_apx = signal.approx_coef
        if abs(a_apx-a_target) < 0.1 and abs(b_apx-b_target) < 0.001 and abs(c_apx-c_target) < 0.01:
            log("PASS", "sigmoid approximation")
        else:
            log("FAIL", "sigmoid approximation")
    except:
        log("FAIL", "sigmoid approximation")


def check_plot_survey():
    try:
        file_name = './test_Excel.xlsx'
        Signals = bs.read_signals(file_name)
        target = bs.TargetType(15.0, 50.0, 5.0, 30.0, 45.0)
        for signal in Signals:
            bs.clean_signal(signal, cut_angle=130.0, flag_plot=False)
            bs.sigmoid_approximation(signal)
        bs.plot_survey(Signals, 15.0, target, title='test', flag_show=True, flag_save=False)
        log("PASS", "plot survey")
    except:
        log("FAIL", "plot survey")
    return


def main():

    log("\nPASS", "gkn_bolts_survey installed")
    try:
        check_numpy()
        check_matplotlib()
        check_pandas()
        check_read_AtlasCopco_files()
        check_read_Excel_files()
        check_sigmoid_approximation()
        check_plot_survey()
    except Exception:
        log("\nFAIL", "something went wrong")


if __name__ == "__main__":
    main()

==> gkn_bolts_survey-0.1.7.tar.gz: gkn_bolts_survey-0.1.7/gkn_bolts_survey/tests/test.py <==
import os
import sys
import time
# import traceback
import gkn_bolts_survey as bs


def log(*m):
    print(" ".join(map(str, m)))


def check_numpy():
    try:
        import numpy
        log("PASS", "NumPy installed")
    except ModuleNotFoundError:
        log("FAIL", "NumPy not installed")


def check_matplotlib():
    try:
        import matplotlib
        log("PASS", "matplotlib installed")
    except ModuleNotFoundError:
        log("FAIL", "matplotlib not installed")


def check_pandas():
    try:
        import pandas
        log("PASS", "pandas installed")
    except ModuleNotFoundError:
        log("FAIL", "pandas not installed")


def check_read_AtlasCopco_files():
    try:
        file_name = './test_AtlasCopco.xls'
        Signals = bs.read_signals(file_name)
        flag_pass = True
        if len(Signals) != 5:   flag_pass = False
        if abs(Signals[0].torque.sum() - 7827.592) > 0.1:   flag_pass = False
        if flag_pass:
            log("PASS", "read AtlasCopco files")
        else:
            log("FAIL", "read AtlasCopco files")
    except:
        log("FAIL", "read AtlasCopco files")


def check_read_Excel_files():
    try:
        file_name = './test_Excel.xlsx'
        Signals = bs.read_signals(file_name)
        flag_pass = True
        if len(Signals) != 4:   flag_pass = False
        if abs(Signals[0].torque.sum() - 2172.49) > 0.1:   flag_pass = False
        if flag_pass:
            log("PASS", "read Excel files")
        else:
            log("FAIL", "read Excel files")
    except:
        log("FAIL", "read Excel files")


def check_signal_approximation():
    try:
        import numpy as np
        a_target = 40.0
        b_target = 0.05
        c_target = -2.0
        angle = np.linspace(0.0, 160.0, 100)
        torque =-(b_target*angle + c_target)
        torque = np.exp(torque) + 1
        torque = a_target / torque
        torque+= 1.3 * np.cos(angle*37.5) * np.sin(angle*15.3)
        signal = bs.SignalType(angle_filter=angle, torque_filter=torque)
        bs.signal_approximation(signal)
        a_apx, b_apx, c_apx = signal.approx_coef
        if abs(a_apx-a_target) < 0.1 and abs(b_apx-b_target) < 0.001 and abs(c_apx-c_target) < 0.01:
            log("PASS", "signal approximation")
        else:
            log("FAIL", "signal approximation")
    except:
        log("FAIL", "signal approximation")


def check_plot_survey():
    try:
        file_name = './test_Excel.xlsx'
        Signals = bs.read_signals(file_name)
        target = bs.TargetType(15.0, 50.0, 5.0, 30.0, 45.0)
        for signal in Signals:
            bs.clean_signal(signal, cut_angle=130.0, flag_plot=False)
            bs.signal_approximation(signal)
        bs.plot_survey(Signals, 15.0, target, title='test', flag_show=True, flag_save=False)
        log("PASS", "plot survey")
    except:
        log("FAIL", "plot survey")
    return


def main():

    log("\nPASS", "gkn_bolts_survey installed")
    try:
        check_numpy()
        check_matplotlib()
        check_pandas()
        check_read_AtlasCopco_files()
        check_read_Excel_files()
        check_signal_approximation()
        check_plot_survey()
    except Exception:
        log("\nFAIL", "something went wrong")


if __name__ == "__main__":
    main()
